///////////////////////////////////////////////////////////////////////////////
//
//  File Name 
//      EVENTMSG.MC
//
//  Description
//      These are the messages for the event logging message ID's
//
//  Author
//      Irving De la Cruz (irvingd@microsoft.com)
//
//  Revision: 1.1
//
// Written for Microsoft Corporation.
// Copyright (c) 1996-1997 Microsoft Corporation. All rights reserved.

#ifndef _EVENTMSG_H_
#define _EVENTMSG_H_

///////////////////////////////////////////////////////////////////////////////
//  Event Log Category
//
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//


//
// Define the severity codes
//
#define STATUS_SEVERITY_WARNING          0x2
#define STATUS_SEVERITY_SUCCESS          0x0
#define STATUS_SEVERITY_INFORMATIONAL    0x1
#define STATUS_SEVERITY_ERROR            0x3


//
// MessageId: DIRMON_CATEGORY
//
// MessageText:
//
//  General Logging
//
#define DIRMON_CATEGORY                  0x00000001L

///////////////////////////////////////////////////////////////////////////////
//  Informational Messages
//
//
// MessageId: EVENTMSG_I_SERVICE_STARTING
//
// MessageText:
//
//  The service is starting.
//
#define EVENTMSG_I_SERVICE_STARTING      0x000003E8L

//
// MessageId: EVENTMSG_I_SERVICE_STARTED
//
// MessageText:
//
//  The service started successfully.
//
#define EVENTMSG_I_SERVICE_STARTED       0x000003E9L

//
// MessageId: EVENTMSG_I_SERVICE_STOPPED
//
// MessageText:
//
//  The service stopped successfully.
//
#define EVENTMSG_I_SERVICE_STOPPED       0x000003EAL

//
// MessageId: EVENTMSG_I_DIR_WATCH_STARTED
//
// MessageText:
//
//  Directory watch has been started on directory %1.
//
#define EVENTMSG_I_DIR_WATCH_STARTED     0x400005DCL

//
// MessageId: EVENTMSG_I_DIR_WATCH_STOPPED
//
// MessageText:
//
//  Completion port and watch threads have terminated.
//
#define EVENTMSG_I_DIR_WATCH_STOPPED     0x400005DDL

//
// MessageId: EVENTMSG_V_FILE_CREATED
//
// MessageText:
//
//  Notification of Change: FILE CREATED - File Name: %1.
//
#define EVENTMSG_V_FILE_CREATED          0x400005DEL

//
// MessageId: EVENTMSG_V_FILE_MODIFIED
//
// MessageText:
//
//  Notification of Change: FILE MODIFIED - File Name: %1.
//
#define EVENTMSG_V_FILE_MODIFIED         0x400005DFL

//
// MessageId: EVENTMSG_V_FILE_DELETED
//
// MessageText:
//
//  Notification of Change: FILE DELETED - File Name: %1
//
#define EVENTMSG_V_FILE_DELETED          0x400005E0L

//
// MessageId: EVENTMSG_V_FILE_RENAMED
//
// MessageText:
//
//  Notification of Change: FILE RENAMED - Old Name: %1   New Name %2
//
#define EVENTMSG_V_FILE_RENAMED          0x400005E1L

///////////////////////////////////////////////////////////////////////////////
//  Error Messages
//
//
// MessageId: EVENTMSG_E_OPEN_REG_CONFIG_KEY
//
// MessageText:
//
//  Failed to open the registry key with the configuration information. Error %1.
//
#define EVENTMSG_E_OPEN_REG_CONFIG_KEY   0xC00007D0L

//
// MessageId: EVENTMSG_E_FAILED_TO_START_SERVICE
//
// MessageText:
//
//  Failed to start the service. Error %1.
//
#define EVENTMSG_E_FAILED_TO_START_SERVICE 0xC00007D1L

//
// MessageId: EVENTMSG_E_FAILED_REGISTRER_CTRL_HANDLER
//
// MessageText:
//
//  Failed to register the service controller handling function. Error %1.
//
#define EVENTMSG_E_FAILED_REGISTRER_CTRL_HANDLER 0xC00007D2L

//
// MessageId: EVENTMSG_E_FAILED_NOTIFY_SCM_STARTING
//
// MessageText:
//
//  Failed to notify the service control manager that we are starting. Error %1.
//
#define EVENTMSG_E_FAILED_NOTIFY_SCM_STARTING 0xC00007D3L

//
// MessageId: EVENTMSG_E_FAILED_CREATE_EVENT
//
// MessageText:
//
//  Failed to create a synchronization event object. Error %1.
//
#define EVENTMSG_E_FAILED_CREATE_EVENT   0xC00007D4L

//
// MessageId: EVENTMSG_E_FAILED_INIT_SESSION
//
// MessageText:
//
//  Failed to initialize messaging subsystem. Error %1.
//
#define EVENTMSG_E_FAILED_INIT_SESSION   0xC00007D5L

//
// MessageId: EVENTMSG_E_FAILED_MAPILOGONEX
//
// MessageText:
//
//  Failed to logon into the messaging subsystem. MAPILogonEx() failed. Error %1.
//
#define EVENTMSG_E_FAILED_MAPILOGONEX    0xC00007D6L

//
// MessageId: EVENTMSG_E_FAILED_GETMSGSTORETABLE
//
// MessageText:
//
//  Failed to get stores table. IMAPISession::GetMsgStoresTable() failed. Error %1.
//
#define EVENTMSG_E_FAILED_GETMSGSTORETABLE 0xC00007D7L

//
// MessageId: EVENTMSG_E_FAILED_HRQUERYALLROWS
//
// MessageText:
//
//  Failed to get table rows. HrQueryAllRows() failed. Error %1.
//
#define EVENTMSG_E_FAILED_HRQUERYALLROWS 0xC00007D8L

//
// MessageId: EVENTMSG_E_FAILED_OPENMSGSTORE
//
// MessageText:
//
//  Failed to open the Exchange PF store. IMAPISession::OpenMsgStore() failed. Error %1.
//
#define EVENTMSG_E_FAILED_OPENMSGSTORE   0xC00007D9L

//
// MessageId: EVENTMSG_E_FAILED_HRGETONEPROP
//
// MessageText:
//
//  Failed to get the entry ID of the PF folder hierarchy. HrGetOneProp() failed. Error %1.
//
#define EVENTMSG_E_FAILED_HRGETONEPROP   0xC00007DAL

//
// MessageId: EVENTMSG_E_FAILED_OPENENTRY
//
// MessageText:
//
//  Failed to open the PF hierarchy folder object. IMAPISession::OpenEntry() failed. Error %1.
//
#define EVENTMSG_E_FAILED_OPENENTRY      0xC00007DBL

//
// MessageId: EVENTMSG_E_FAILED_CREATEFOLDER
//
// MessageText:
//
//  Failed to create the PF folder where the posting will be placed. IMAPIFolder::CreateFolder() failed. Error %1.
//
#define EVENTMSG_E_FAILED_CREATEFOLDER   0xC00007DCL

//
// MessageId: EVENTMSG_E_FAILED_CREATEMESSAGE
//
// MessageText:
//
//  Failed to create message in the PF folder. IMAPIFolder::CreateMessage() failed. Error %1.
//
#define EVENTMSG_E_FAILED_CREATEMESSAGE  0xC00007DDL

//
// MessageId: EVENTMSG_E_FAILED_UNICODE_TO_ANSI
//
// MessageText:
//
//  Failed to convert UNICODE string to ANSI. Error %1.
//
#define EVENTMSG_E_FAILED_UNICODE_TO_ANSI 0xC00007DEL


#endif // _EVENTMSG_H_
